# aut-sdk-python

Create a virtual environment to install all dependencies:

```
python -m venv venv
```

Next, select the environment:
In Windows:

```
venv\Scripts\activate
```

In Unix or MacOS,

```
source venv\bin\activate
```

Once it is done, execute:

```
pip install -r requirements.txt
```

To execute tests:

```
pytest tests/
```